<?php
/*
 * Plugin Name: 3DPrint - Frontend VAT
 * Author: Sergey Burkov
 * Description: Displays price with VAT on the frontend
 * Text Domain: 3dprint-vat
 * WC requires at least: 3.0
 * WC tested up to: 9.7.9
 * Version: 1.0
*/

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

register_activation_hook( __FILE__, 'p3d_vat_check_install' );

add_action( 'before_woocommerce_init', function() {
	if ( class_exists( \Automattic\WooCommerce\Utilities\FeaturesUtil::class ) ) {
		\Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', __FILE__, true );
	}
} );

if ( is_admin() ) {
	include '3dprint-vat-admin.php';
}

add_action( 'wp_enqueue_scripts', 'p3d_vat_enqueue_scripts_frontend' );
function p3d_vat_enqueue_scripts_frontend() {
	$settings = get_option( '3dp_vat_settings' );
	if ($settings['vat_type']=='incl') {
		wp_enqueue_script( 'p3d-vat-script.js',  plugin_dir_url( __FILE__ ).'js/vat_incl.js', array( '3dprint-frontend.js' ), '1.0' );
	}
	else {
		wp_enqueue_script( 'p3d-vat-script.js',  plugin_dir_url( __FILE__ ).'js/vat_excl.js', array( '3dprint-frontend.js' ), '1.0' );
	}

	wp_localize_script( 'p3d-vat-script.js', 'p3d_vat',
		array(
			'vat_pct' => $settings['vat_pct'],
			'text_vat' => __('VAT', '3dprint-vat'),
			'text_net_price' => __('Net price', '3dprint-vat'),
			'text_gross_price' => __('Gross price', '3dprint-vat')
		)
	);
	$custom_css = "
		#p3d-amount-text {
		  display: none;
		}
	";
	wp_add_inline_style( '3dprint-frontend.css', $custom_css );


}

function p3d_vat_check_install() {
	global $wpdb;
	$current_settings = get_option( '3dp_vat_settings' );
	$settings=array(
		'vat_pct' => (isset($current_settings['vat_pct']) ? $current_settings['vat_pct'] : '0'),
		'vat_type' => (isset($current_settings['vat_type']) ? $current_settings['vat_type'] : 'incl')
	);
	update_option( '3dp_vat_settings', $settings );
}



?>